@@ -3,7 +3,7 @@
 #' @description
 #' Main user interface for estimating marginal hazard ratios using propensity
 #' score weighting. Supports binary and multiple treatment groups with various
-#' weighting schemes (ATE, ATT, overlap) and optional trimming. Variance can be
+#' weighting schemes (IPW, OW, or ATT) and optional trimming. Variance can be
 #' estimated via bootstrap or robust sandwich estimator.
 #'
 #' @param data Data frame containing treatment, survival outcome, and covariates.
@@ -13,12 +13,19 @@
 #'   Should be coded as 1=event, 0=censored.
 #' @param reference_level Treatment level to use as reference in Cox model. MANDATORY.
 #'   Must be one of the treatment levels.
-#' @param estimand Target estimand: "ATE" (average treatment effect), "ATT" (average
-#'   treatment effect on the treated), or "overlap" (overlap weighting). Default "ATE".
-#' @param att_group Target group for ATT. Required if \code{estimand = "ATT"}.
-#' @param trim Trimming method: "symmetric" or "asymmetric". Default NULL (no trimming).
-#' @param delta Threshold for symmetric trimming (e.g., 0.1). Required if \code{trim = "symmetric"}.
-#' @param alpha Percentile for asymmetric trimming (e.g., 0.05). Required if \code{trim = "asymmetric"}.
+#' @param weight_method Weighting method: "IPW" (inverse probability weighting),
+#'   "OW" (overlap weighting), or "ATT" (average treatment effect on the treated).
+#'   Default "IPW".
+#' @param att_group Target group for ATT. Required if \code{weight_method = "ATT"}.
+#' @param trim Logical. Perform symmetric propensity score trimming? Default FALSE.
+#'   If TRUE, symmetric trimming is applied (Crump extension for multiple treatments).
+#'   See \code{\link{estimate_weights}} for trimming details. Ignored if
+#'   \code{weight_method = "OW"}. Asymmetric trimming is no longer supported due to
+#'   poor statistical performance.
+#' @param delta Threshold for symmetric trimming in \eqn{(0, 1/J]}, where \eqn{J} is the number
+#'   of treatment levels. Default NULL uses recommended values: 0.1 for binary
+#'   treatment, 0.067 for 3 groups, \eqn{1/(2J)} for \eqn{J \ge 4} (Yoshida et al., 2019).
+#'   Used only if \code{trim = TRUE}.
 #' @param variance_method Variance estimation method: "bootstrap" (default) or "robust".
 #'   "bootstrap" resamples the entire analysis pipeline. "robust" uses the sandwich
 #'   variance estimator from \code{coxph()} without bootstrap.
@@ -63,11 +70,33 @@
 #'     Contains: boot_samples, boot_allocation, n_success_by_group, B.}
 #'
 #' @details
+#' **Weighting Methods:**
+#'
+#' The \code{weight_method} parameter specifies the target population for causal
+#' inference:
+#'
+#' \itemize{
+#'   \item \strong{IPW (Inverse Probability Weighting)}: Observations are weighted
+#'     by the inverse probability of their observed treatment, \eqn{w_i = 1/e_j(X_i)}
+#'     where j is the observed treatment group. Inference targets the combined
+#'     population (ATE type).
+#'
+#'   \item \strong{OW (Overlap Weighting)}: Observations are weighted by overlap
+#'     weights, which extends to multiple treatment groups (Li et al., 2018;
+#'     Li and Li, 2019). Inference targets the population at clinical equipoise
+#'     (overlap population).
+#'
+#'   \item \strong{ATT (Average Treatment Effect on the Treated)}: IPW weights
+#'     tilted toward a specified target group. Observations in the target group
+#'     receive weight 1, others receive \eqn{w_i = e_{\text{target}}(X_i) / e_j(X_i)}.
+#'     Inference targets the specified treatment group population (ATT type).
+#' }
+#'
 #' **Analysis Workflow:**
 #' 1. Extract treatment variable from \code{ps_formula}.
 #' 2. Estimate propensity scores using multinomial logistic regression (or logistic
 #'    for binary treatment).
-#' 3. Calculate propensity score weights based on \code{estimand} and optional \code{trim}.
+#' 3. Calculate propensity score weights based on \code{weight_method} and optional \code{trim}.
 #' 4. Fit marginal Cox model \code{Surv(time, event) ~ treatment} with weights.
 #' 5. Estimate variance via bootstrap (resampling full pipeline) or robust sandwich
 #'    estimator.
@@ -78,11 +107,6 @@
 #' - \code{robust}: Uses robust sandwich variance from \code{coxph()} directly. No
 #'   bootstrap performed (faster but may be less accurate with extreme weights).
 #'
-#' **Trimming:**
-#' - Symmetric: Crump extension for multiple treatments (Yoshida et al., 2019).
-#' - Asymmetric: Sturmer extension for multiple treatments (Yoshida et al., 2019).
-#' - Not supported with overlap weights (already bounded [0,1]).
-#'
 #' @examples
 #' \donttest{
 #' # Example 1: Binary treatment with overlap weighting
@@ -93,7 +117,7 @@
 #'   time_var = "time",
 #'   event_var = "event",
 #'   reference_level = "A",
-#'   estimand = "overlap"
+#'   weight_method = "OW"
 #' )
 #' summary(result1)
 #'
@@ -105,7 +129,7 @@
 #'   time_var = "time",
 #'   event_var = "event",
 #'   reference_level = "C",
-#'   estimand = "ATT",
+#'   weight_method = "ATT",
 #'   att_group = "C",
 #'   variance_method = "robust"
 #' )
@@ -113,6 +137,10 @@
 #' }
 #'
 #' @references
+#' Li, F., Morgan, K. L., & Zaslavsky, A. M. (2018). Balancing covariates via
+#' propensity score weighting. \emph{Journal of the American Statistical Association},
+#' 113(521), 390-400.
+#'
 #' Li, F., & Li, F. (2019). Propensity score weighting for causal inference with
 #' multiple treatments. \emph{The Annals of Applied Statistics}, 13(4), 2389-2415.
 #'
@@ -126,11 +154,10 @@ marCoxph <- function(data,
                      time_var,
                      event_var,
                      reference_level,
-                     estimand = "ATE",
+                     weight_method = "IPW",
                      att_group = NULL,
-                     trim = NULL,
+                     trim = FALSE,
                      delta = NULL,
-                     alpha = NULL,
                      variance_method = "bootstrap",
                      boot_level = "full",
                      B = 100,
@@ -141,7 +168,41 @@ marCoxph <- function(data,
                      robust = TRUE) {
 
   # ============================================================================
-  # STEP 1: Input Validation and Data Cleaning
+  # STEP 1: Map user-facing parameters to internal implementation
+  # ============================================================================
+  # NOTE: This mapping layer is a temporary strategy to align the user-facing API
+  # (weight_method, trim as logical) with the internal implementation (estimand,
+  # trim as character) and to disable asymmetric trimming without extensive
+  # refactoring of downstream functions.
+
+  # Validate weight_method
+  if (!weight_method %in% c("IPW", "OW", "ATT")) {
+    stop("'weight_method' must be 'IPW', 'OW', or 'ATT'.", call. = FALSE)
+  }
+
+  # Validate OW + trim combination (before transforming trim)
+  if (weight_method == "OW" && trim) {
+    stop("Trimming is not supported with overlap weights.\n",
+         "  Overlap weights already downweight tail populations and are bounded [0,1].\n",
+         "  Use weight_method = 'IPW' or 'ATT' with trim if needed.",
+         call. = FALSE)
+  }
+
+  # Map weight_method to internal estimand
+  estimand <- switch(weight_method,
+                     "IPW" = "ATE",
+                     "OW" = "overlap",
+                     "ATT" = "ATT")
+
+  # Transform trim from logical to character/NULL for internal use
+  trim <- if (trim) "symmetric" else NULL
+
+  # Set delta and alpha for internal use
+  delta <- if (!is.null(trim)) delta else NULL
+  alpha <- NULL  # Asymmetric trimming no longer supported
+
+  # ============================================================================
+  # STEP 1b: Input Validation and Data Cleaning
   # ============================================================================
 
   # Basic parameter validation
@@ -154,16 +215,6 @@ marCoxph <- function(data,
   if (!variance_method %in% c("bootstrap", "robust")) {
     stop("'variance_method' must be 'bootstrap' or 'robust'", call. = FALSE)
   }
-  if (!estimand %in% c("ATE", "ATT", "overlap")) {
-    stop("'estimand' must be 'ATE', 'ATT', or 'overlap'", call. = FALSE)
-  }
-  if (estimand == "overlap" && !is.null(trim)) {
-    stop("Trimming is not supported with overlap weights.\n",
-         "  Use estimand = 'ATE' or 'ATT' with trim if needed.", call. = FALSE)
-  }
-  if (!is.null(trim) && !trim %in% c("symmetric", "asymmetric")) {
-    stop("'trim' must be NULL, 'symmetric', or 'asymmetric'", call. = FALSE)
-  }
   if (!is.list(ps_control)) {
     stop("'ps_control' must be a list.", call. = FALSE)
   }
